@@ -1,6 +1,6 @@
 /*
  * Adplug - Replayer for many OPL2/OPL3 audio file formats.
- * Copyright (C) 1999 - 2006 Simon Peter, <dn.tlp@gmx.net>, et al.
+ * Copyright (C) 1999 - 2008 Simon Peter, <dn.tlp@gmx.net>, et al.
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -177,7 +177,7 @@ bool Cd00Player::update()
       setvolume(c);
     }
 
-    if(channel[c].levpuls != 0xff)	// Levelpuls
+    if(channel[c].levpuls != 0xff) {	// Levelpuls
       if(channel[c].frameskip)
 	channel[c].frameskip--;
       else {
@@ -193,6 +193,7 @@ bool Cd00Player::update()
 	channel[c].modvol += levpuls[channel[c].levpuls].voladd; channel[c].modvol &= 63;
 	setvolume(c);
       }
+    }
   }
 
   // song handling
@@ -250,6 +251,7 @@ bool Cd00Player::update()
 	patt = (unsigned short *)((char *)filedata + LE_WORD(&seqptr[ord]));
 	break;
       }
+    channel[c].fxflag = 0;
     readseq:	// process sequence (pattern)
       if(!version)	// v0: always initialize rhcnt
 	channel[c].rhcnt = channel[c].irhcnt;
@@ -281,7 +283,10 @@ bool Cd00Player::update()
 	  break;
 	default:					// play note
 	  // restart fx
-	  channel[c].slideval = 0; channel[c].slide = 0; channel[c].vibdepth = 0;
+	  if(!(channel[c].fxflag & 1))
+	    channel[c].vibdepth = 0;
+	  if(!(channel[c].fxflag & 2))
+	    channel[c].slideval = channel[c].slide = 0;
 
 	  if(version) {	// note handling for v1 and above
 	    if(note > 0x80)	// locked note (no channel transpose)
@@ -349,6 +354,7 @@ bool Cd00Player::update()
 	  channel[c].vibspeed = fxop & 0xff;
 	  channel[c].vibdepth = fxop >> 8;
 	  channel[c].trigger = fxop >> 9;
+	  channel[c].fxflag |= 1;
 	  break;
 	case 8:		// v0: Duration
 	  if(!version)
@@ -380,9 +386,11 @@ bool Cd00Player::update()
 	  break;
 	case 0xd:	// Slide up
 	  channel[c].slide = fxop;
+	  channel[c].fxflag |= 2;
 	  break;
 	case 0xe:	// Slide down
 	  channel[c].slide = -fxop;
+	  channel[c].fxflag |= 2;
 	  break;
 	}
 	goto readseq;	// event is incomplete, note follows
@@ -406,6 +414,8 @@ void Cd00Player::rewind(int subsong)
   } *tpoin;
   int i;
 
+  if(subsong == -1) subsong = cursubsong;
+
   if(version > 1) {	// do nothing if subsong > number of subsongs
     if(subsong >= header->subsongs)
       return;
@@ -435,6 +445,7 @@ void Cd00Player::rewind(int subsong)
   }
   songend = 0;
   opl->init(); opl->write(1,32);	// reset OPL chip
+  cursubsong = subsong;
 }
 
 std::string Cd00Player::gettype()
