@@ -1,6 +1,6 @@
 /*
  * AdPlug - Replayer for many OPL2/OPL3 audio file formats.
- * Copyright (C) 1999 - 2006 Simon Peter, <dn.tlp@gmx.net>, et al.
+ * Copyright (C) 1999 - 2007 Simon Peter, <dn.tlp@gmx.net>, et al.
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -65,9 +65,11 @@ class Cd00Player: public CPlayer
 #pragma pack()
 
   struct {
-    unsigned short	*order,ordpos,pattpos,del,speed,rhcnt,key,freq,inst,spfx,ispfx,irhcnt;
+    unsigned short	*order,ordpos,pattpos,del,speed,rhcnt,key,freq,inst,
+      spfx,ispfx,irhcnt;
     signed short	transpose,slide,slideval,vibspeed;
-    unsigned char	seqend,vol,vibdepth,fxdel,modvol,cvol,levpuls,frameskip,nextnote,note,ilevpuls,trigger;
+    unsigned char	seqend,vol,vibdepth,fxdel,modvol,cvol,levpuls,
+      frameskip,nextnote,note,ilevpuls,trigger,fxflag;
   } channel[9];
 
   struct Sinsts {
@@ -89,7 +91,7 @@ class Cd00Player: public CPlayer
     unsigned char duration,ptr;
   } *levpuls;
 
-  unsigned char songend,version;
+  unsigned char songend,version,cursubsong;
   char *datainfo;
   unsigned short *seqptr;
   d00header *header;
