@@ -1,6 +1,6 @@
 /*
  * Adplug - Replayer for many OPL2/OPL3 audio file formats.
- * Copyright (C) 1999 - 2003 Simon Peter, <dn.tlp@gmx.net>, et al.
+ * Copyright (C) 1999 - 2006 Simon Peter, <dn.tlp@gmx.net>, et al.
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,6 +20,7 @@
  *
  * Visit:  http://tenacity.hispeed.com/aomit/oplx/
  */
+#include <cstring>
 #include <algorithm>
 
 #include "rol.h"
@@ -95,7 +96,7 @@ bool CrolPlayer::load(const std::string &filename, const CFileProvider &fp)
 {
     binistream *f = fp.open(filename); if(!f) return false;
 
-    char *fn = new char[filename.length()+9];
+    char *fn = new char[filename.length()+12];
     int i;
     std::string bnk_filename;
 
@@ -665,7 +666,7 @@ int CrolPlayer::load_rol_instrument( binistream *f, SBnkHeader const &header, st
     else
     {
         // set up default instrument data here
-        memset( &usedIns.instrument, 0, kSizeofDataRecord );
+        memset( &usedIns.instrument, 0, sizeof(SRolInstrument) );
     }
     ins_list.push_back( usedIns );
 
